pub trait FileSystem {
    type HashedFileIn: HashedFileIn;

    // Required method
    fn open_hashed_file<'life0, 'async_trait>(
        &'life0 self,
        path: impl 'async_trait + Into<String> + Send
    ) -> Pin<Box<dyn Future<Output = Result<Self::HashedFileIn, Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn open_compressed_hashed_file<'life0, 'async_trait>(
        &'life0 self,
        path: impl 'async_trait + Into<String> + Send
    ) -> Pin<Box<dyn Future<Output = Result<CompressedHashedFileIn<Self::HashedFileIn>, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
}
Asynchronous file system.

Required Associated Types

source

type HashedFileIn: HashedFileIn

File whose contents can be verified with the hash.

Required Methods

source

fn open_hashed_file<'life0, 'async_trait>( &'life0 self, path: impl 'async_trait + Into<String> + Send ) -> Pin<Box<dyn Future<Output = Result<Self::HashedFileIn, Error>> + Send + 'async_trait>>where Self: 'async_trait, 'life0: 'async_trait,

Opens a file whose contents can be verified with the hash.

Provided Methods

source

fn open_compressed_hashed_file<'life0, 'async_trait>( &'life0 self, path: impl 'async_trait + Into<String> + Send ) -> Pin<Box<dyn Future<Output = Result<CompressedHashedFileIn<Self::HashedFileIn>, Error>> + Send + 'async_trait>>where Self: Sync + 'async_trait, 'life0: 'async_trait,

Opens a compressed file whose contents can be verified with the hash.

Implementors