pub struct QueryResult<'db, T, FS>where
    T: Send,
    FS: Send,{ /* private fields */ }
Query result.

Can be derefed as a PartitionQueryResult.

Implementations

source

impl<'db, T, FS> QueryResult<'db, T, FS>where T: Send, FS: Send,

source

pub fn get_attribute<'i, 'k, K>( &'i self, key: &'k K ) -> GetAttributeInPartition<'db, 'i, 'k, T, FS, K> where String: Borrow<K>, K: Hash + Eq + Send + ?Sized, 'i: 'db,

Returns an attribue value of the vector corresponding to the result.

The first call of this function on a result belonging to a partition will take longer because it will load the attributes of the partition.