pub trait LoadAttributesLog<'db> {
    // Required method
    fn load_attributes_log<'async_trait>(
        &'db self,
        index: usize
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'db: 'async_trait;
}
Capability of loading the attributes log of a partition.

Supposed to be specialized for a specific Database.

Required Methods

source

fn load_attributes_log<'async_trait>( &'db self, index: usize ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where Self: 'async_trait, 'db: 'async_trait,

Loads the attributes log of a partition in the database.

Fails if index is out of bounds.

Implementors

source

impl<'db, T, FS> LoadAttributesLog<'db> for Database<T, FS>where T: Send + Sync, FS: FileSystem + Send + Sync, Self: LoadPartition<'db, T> + Sync,