Struct flechasdb::db::stored::Database

source ·
pub struct Database<T, FS> { /* private fields */ }
Stored database.

Implementations

source

impl<T, FS> Database<T, FS>where FS: FileSystem,

source

pub fn vector_size(&self) -> usize

Returns the vector size.

source

pub fn num_partitions(&self) -> usize

Returns the number of partitions.

source

pub fn num_divisions(&self) -> usize

Returns the number of subvector divisions.

source

pub fn num_codes(&self) -> usize

Returns the number of codes in each codebook.

source

pub fn subvector_size(&self) -> usize

Returns the subvector size.

source

pub fn get_partition_id(&self, index: usize) -> Option<&String>

Returns the ID of a partition.

None if indexnum_partitions.

source

pub fn get_codebook_id(&self, index: usize) -> Option<&String>

Returns a code vector in a specified division.

None if indexnum_divisons.

source

impl<T, FS> Database<T, FS>where FS: FileSystem, Self: LoadPartition<T>,

source

pub fn get_attribute<K>( &self, vector_id: &Uuid, key: &K ) -> Result<Option<AttributeValueRef<'_>>, Error>where String: Borrow<K>, K: Hash + Eq + ?Sized,

Returns an attribute value of a given vector.

The first call to this function will take longer because it loads all the attributes. If you want to get attributes of your query results, please use QueryResult::get_attribute instead.

None if the vector exists but no value is associated with key.

Fails if no vector is associated with vector_id.

source

impl<T, FS> Database<T, FS>where T: Scalar, FS: FileSystem, Self: LoadPartition<T> + LoadCodebook<T> + LoadPartitionCentroids<T>,

source

pub fn query<'a, V>( &'a self, v: &V, k: NonZeroUsize, nprobe: NonZeroUsize ) -> Result<Vec<QueryResult<'a, T, FS>>, Error>where V: AsSlice<T> + ?Sized,

Queries k-nearest neighbors (k-NN) of a given vector.

The first call to this function will take longer because it lazily loads partition centroids, and codebooks.

source

pub fn query_with_events<'a, V, EventHandler>( &'a self, v: &V, k: NonZeroUsize, nprobe: NonZeroUsize, event: EventHandler ) -> Result<Vec<QueryResult<'a, T, FS>>, Error>where V: AsSlice<T> + ?Sized, EventHandler: FnMut(QueryEvent),

Queries k-nearest neighbors (k-NN) of a given vector.

The first call to this function will take longer because it lazily loads partition centroids, and codebooks.