pub struct WeightedIndex<X>where
    X: SampleUniform + PartialOrd,{ /* private fields */ }
Straightforward weighted distribution.

Unlike rand::distributions::weighted::WeightedIndex, this distribution won’t precalculate the cumulative weights, but will do it on the fly.

Implementations

source

impl<X> WeightedIndex<X>where X: SampleUniform + Zero + AddAssign + SubAssign + PartialOrd + Copy,

source

pub fn new(weights: Vec<X>) -> Result<Self, Error>

Creates a new WeightedIndex from a given Vec.

Fails if weights is empty, or if any of the weights is negative, or if the sum of all weights is zero.

source

pub fn update(&mut self, new_weights: &[(usize, &X)]) -> Result<(), Error>

Updates the weights.

Fails if the total weight will become zero, or if any of the new weight is negative, or if any of the weight indices is out of range.

In case update fails, the weights are not changed.

source

pub fn get_weight(&self, index: usize) -> X

Returns the weight.