pub trait HashedFileIn: Read {
    // Required method
    fn verify(self) -> Result<(), Error>;
}
File whose name is the hash of its contents.

Required Methods

source

fn verify(self) -> Result<(), Error>

Verifies the file.

Finishes the calculation of the hash and verifies the file. You should call this function after the entire file has been read.

File name is supposed to be a Base64 encoded URL-safe SHA256 digest.

Implementors