Function flechasdb::linalg::max_abs_naive
source · pub fn max_abs_naive<T>(xs: &[T]) -> Option<T>where
T: Abs + PartialOrd + Copy,Expand description
Locates the maximum absolute value in a given vector.
pub fn max_abs_naive<T>(xs: &[T]) -> Option<T>where
T: Abs + PartialOrd + Copy,Locates the maximum absolute value in a given vector.