pub fn norm2_naive_check<T>(xs: &[T]) -> Twhere
    T: Abs + One + Sqrt + Zero + AddAssign + Div<Output = T> + Mul<Output = T> + PartialOrd + PartialEq + Copy,
Calculates the Euclidean norm of a given vector.

This function will produce a more accurate result if xs contains an extermely large or small value.