pub trait Serialize<M>where
M: Message,{
// Required method
fn serialize(&self) -> Result<M, Error>;
}Expand description
Represents a type that can be serialized as a message.
pub trait Serialize<M>where
M: Message,{
// Required method
fn serialize(&self) -> Result<M, Error>;
}Represents a type that can be serialized as a message.