pub struct BlockVectorSet<T> {
    pub vector_size: usize,
    /* private fields */
}
Vectors in a contiguous array.

Fields

vector_size: usize

Vector size.

Implementations

source

impl<T> BlockVectorSet<T>

source

pub fn chunk(data: Vec<T>, vector_size: NonZeroUsize) -> Result<Self, Error>

Tries to chunk a given Vec.

Fails if data.len is not a multiple of vector_size.

source

pub fn len(&self) -> usize

Returns the number of vectors in the vector set.

source

pub const fn vector_size(&self) -> usize

Returns the size of each vector in the vector set.

source

pub fn get(&self, i: usize) -> &[T]

Returns the i-th vector in the vector set.

Panics if i is out of bounds.

source

pub fn get_mut(&mut self, i: usize) -> &mut [T]

Returns the mutable i-th vector.