pub struct QueryResult<'db, T, FS>where
T: Send,
FS: Send,{ /* private fields */ }Expand description
Query result.
Can be derefed as a PartitionQueryResult.
Implementations
sourceimpl<'db, T, FS> QueryResult<'db, T, FS>where
T: Send,
FS: Send,
impl<'db, T, FS> QueryResult<'db, T, FS>where T: Send, FS: Send,
sourcepub fn get_attribute<'i, 'k, K>(
&'i self,
key: &'k K
) -> GetAttributeInPartition<'db, 'i, 'k, T, FS, K> ⓘwhere
String: Borrow<K>,
K: Hash + Eq + Send + ?Sized,
'i: 'db,
pub fn get_attribute<'i, 'k, K>( &'i self, key: &'k K ) -> GetAttributeInPartition<'db, 'i, 'k, T, FS, K> ⓘwhere String: Borrow<K>, K: Hash + Eq + Send + ?Sized, 'i: 'db,
Returns an attribue value of the vector corresponding to the result.
The first call of this function on a result belonging to a partition will take longer because it will load the attributes of the partition.