pub struct Database<T, FS> { /* private fields */ }Expand description
Stored database.
Implementations
sourceimpl<T, FS> Database<T, FS>where
FS: FileSystem,
impl<T, FS> Database<T, FS>where FS: FileSystem,
sourcepub fn vector_size(&self) -> usize
pub fn vector_size(&self) -> usize
Returns the vector size.
sourcepub fn num_partitions(&self) -> usize
pub fn num_partitions(&self) -> usize
Returns the number of partitions.
sourcepub fn num_divisions(&self) -> usize
pub fn num_divisions(&self) -> usize
Returns the number of subvector divisions.
sourcepub fn subvector_size(&self) -> usize
pub fn subvector_size(&self) -> usize
Returns the subvector size.
sourcepub fn get_partition_id(&self, index: usize) -> Option<&String>
pub fn get_partition_id(&self, index: usize) -> Option<&String>
Returns the ID of a partition.
None if index ≥ num_partitions.
sourcepub fn get_codebook_id(&self, index: usize) -> Option<&String>
pub fn get_codebook_id(&self, index: usize) -> Option<&String>
Returns a code vector in a specified division.
None if index ≥ num_divisons.
sourceimpl<T, FS> Database<T, FS>where
FS: FileSystem,
Self: LoadPartition<T>,
impl<T, FS> Database<T, FS>where FS: FileSystem, Self: LoadPartition<T>,
sourcepub fn get_attribute<K>(
&self,
vector_id: &Uuid,
key: &K
) -> Result<Option<AttributeValueRef<'_>>, Error>where
String: Borrow<K>,
K: Hash + Eq + ?Sized,
pub fn get_attribute<K>( &self, vector_id: &Uuid, key: &K ) -> Result<Option<AttributeValueRef<'_>>, Error>where String: Borrow<K>, K: Hash + Eq + ?Sized,
Returns an attribute value of a given vector.
The first call to this function will take longer because it loads all
the attributes.
If you want to get attributes of your query results, please use
QueryResult::get_attribute instead.
None if the vector exists but no value is associated with key.
Fails if no vector is associated with vector_id.
sourceimpl<T, FS> Database<T, FS>where
T: Scalar,
FS: FileSystem,
Self: LoadPartition<T> + LoadCodebook<T> + LoadPartitionCentroids<T>,
impl<T, FS> Database<T, FS>where T: Scalar, FS: FileSystem, Self: LoadPartition<T> + LoadCodebook<T> + LoadPartitionCentroids<T>,
sourcepub fn query<'a, V>(
&'a self,
v: &V,
k: NonZeroUsize,
nprobe: NonZeroUsize
) -> Result<Vec<QueryResult<'a, T, FS>>, Error>where
V: AsSlice<T> + ?Sized,
pub fn query<'a, V>( &'a self, v: &V, k: NonZeroUsize, nprobe: NonZeroUsize ) -> Result<Vec<QueryResult<'a, T, FS>>, Error>where V: AsSlice<T> + ?Sized,
Queries k-nearest neighbors (k-NN) of a given vector.
The first call to this function will take longer because it lazily loads partition centroids, and codebooks.
sourcepub fn query_with_events<'a, V, EventHandler>(
&'a self,
v: &V,
k: NonZeroUsize,
nprobe: NonZeroUsize,
event: EventHandler
) -> Result<Vec<QueryResult<'a, T, FS>>, Error>where
V: AsSlice<T> + ?Sized,
EventHandler: FnMut(QueryEvent),
pub fn query_with_events<'a, V, EventHandler>( &'a self, v: &V, k: NonZeroUsize, nprobe: NonZeroUsize, event: EventHandler ) -> Result<Vec<QueryResult<'a, T, FS>>, Error>where V: AsSlice<T> + ?Sized, EventHandler: FnMut(QueryEvent),
Queries k-nearest neighbors (k-NN) of a given vector.
The first call to this function will take longer because it lazily loads partition centroids, and codebooks.