Trait flechasdb::io::HashedFileIn
source · pub trait HashedFileIn: Read {
// Required method
fn verify(self) -> Result<(), Error>;
}Expand description
File whose name is the hash of its contents.
pub trait HashedFileIn: Read {
// Required method
fn verify(self) -> Result<(), Error>;
}File whose name is the hash of its contents.