Trait flechasdb::io::HashedFileOut
source · pub trait HashedFileOut: Write {
// Required method
fn persist(self, extension: impl AsRef<str>) -> Result<String, Error>;
}Expand description
File whose name will be the hash of its contents.
Required Methods
sourcefn persist(self, extension: impl AsRef<str>) -> Result<String, Error>
fn persist(self, extension: impl AsRef<str>) -> Result<String, Error>
Persists the file.
Finishes the calculation of the hash and persists the file. You should flush the stream before calling this function.
Returns the encoded hash value that is supposed to be a URS-safe Base64 encoded SHA256 digest.